@@ -26,8 +26,9 @@ except:
 
 def call_notifator(msg):
     if NOTIF:
+        print("i... calling bot_send")
         host = socket.gethostname()
-        msg2 =  msg+"@"+host
+        msg2 =  msg+"\n\n@"+host
         print(msg2)
         bot_send("Backups", msg2 )
     else:
@@ -39,7 +40,7 @@ def call_command(CMD):
         res=sp.check_output( CMD, shell=True ).decode("utf8").rstrip().split("\n")
     except sp.CalledProcessError as e:
         print("X...  ...........................ERROR when calling", CMD)
-        print(e.returncode)
+        # print("D... err=",e.returncode)
         call_notifator("XXX-"+CMD.split()[-1])
         # sys.exit(e.returncode)
     return res
@@ -150,7 +151,7 @@ use: sshborg create_and_prune_defaults --configfile ~/.borgssh.conf
             folder = folder.rstrip("/")
             print("i...  CREATE AND PRUNE:",folder)
             create_and_prune(folder,debug, configfile=configfile)
-            report = report + " " + folder
+            report = report + " " + folder + "\n\n"
     call_notifator( report ) # only here I call telegram
     return True
 
@@ -159,18 +160,24 @@ use: sshborg create_and_prune_defaults --configfile ~/.borgssh.conf
 def listborg(debug = False, configfile=""):
     """ borg list ssh://borg@***:2222/config/borg"""
     global print
+    print("i... list borg")
     conf.load_config(configfile)
     print=super_print(debug)(print)
 
     CMD = "borg list ssh://borg@{}:2222/config/borg".format(
         conf.CONFIG['remote']
         )
-    print(CMD)
+    print("i... CMD=",CMD)
     # direct terminal output
     # res=sp.check_output( CMD, shell=True ).decode("utf8").rstrip().split("\n")
     res = call_command( CMD )
-    for i in res:
-        print(i[:80])
+    if res[0]!="X":
+        for i in res:
+            print(i[:80])
+        print("X... Xprinting output")
+    else:
+        print("X... error, X... output printing")
+        print(res)
     return True
 
 
@@ -228,7 +235,7 @@ borg info ssh://borg@***:2222/config/borg"""
 
 
 if __name__ == "__main__":
-    print("i... in the __main__ of uname of borgssh")
+    # print("i... in the __main__ of uname of borgssh")
     Fire({"init":init,
         "create":create,
           "prune":prune,
